api library
Classes
- ApiClient
- DeserializationMessage
- Primarily intended for use in an isolate.
- DeviceBriefing
- DeviceConnection
- Error
- HealthApi
- SetupApi
- StateManagerDevice
- StateManagerDeviceService
- StateManagerDeviceServiceStatus
- StateManagerDeviceServiceStatusTypeTransformer
- Transformation class that can encode an instance of StateManagerDeviceServiceStatus to String, and decode dynamic data back to StateManagerDeviceServiceStatus.
- StateManagerDeviceStatus
- StateManagerDeviceStatusTypeTransformer
- Transformation class that can encode an instance of StateManagerDeviceStatus to String, and decode dynamic data back to StateManagerDeviceStatus.
- StateManagerService
- StateManagerServiceTypeTransformer
- Transformation class that can encode an instance of StateManagerService to String, and decode dynamic data back to StateManagerService.
- StatusApi
- SupervisorApplication
- SupervisorData
- SupervisorDevice
- SupervisorService
Properties
- authenticator ↔ LogbotHttpBearerAuth
-
getter/setter pair
- defaultApiClient ↔ ApiClient
-
getter/setter pair
Functions
- Format a map of cookies to a header cookies String. LOGBOT: added this to support cookies
-
deserializeAsync(
DeserializationMessage message) → Future - Primarily intended for use in an isolate.
-
mapCastOfType<
K, V> (dynamic map, String key) → Map< K, V> ? -
Returns a valid Map<K, V> found at the specified Map
key, null otherwise. -
mapDateTime(
dynamic map, String key, [String? pattern]) → DateTime? -
Returns a valid DateTime found at the specified Map
key, null otherwise. -
mapValueOfType<
T> (dynamic map, String key) → T? -
Returns a valid
Tvalue found at the specified Mapkey, null otherwise. -
parameterToString(
dynamic value) → String - Format the given parameter object into a String.
-
serializeAsync(
Object? value) → Future< String> - Primarily intended for use in an isolate.