StateManagerService class

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
The underlying value of this enum member.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() String
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromJson(dynamic value) StateManagerService?
listFromJson(dynamic json, {bool growable = false}) List<StateManagerService>?

Constants

LB_FIREWALL → const StateManagerService
  • LB_FIREWALL: lb_firewall service
  • LB_SETUP → const StateManagerService
  • LB_SETUP: lb_setup service, versions >= 2.0.0
  • LB_WRITER → const StateManagerService
  • LB_WRITER: lb_writer service
  • values → const List<StateManagerService>
    List of all possible values in this StateManagerService.